#use this only for bleaching data of 1 FP (not all FPs combined)

library(data.table)
library(tidyr)
library(dplyr)
library(gtools)
library(stringr)
library(magrittr)
titel <- "FPtest" #specify FP type
minutesperframe <- 1   #keep 1, model will do this

#import data
wd <<- choose.dir()     #set input folder
setwd(wd)              #set input folder
filelist = list.files(pattern = "results.*.txt")       #make a list with all the txtfiles in a folder
datalist = lapply(filelist, function(x)read.table(x, sep="\t", header=T)) 
combined = do.call("smartbind", datalist) 

combined$X <- combined$X*minutesperframe    #don't change this, model will do this
combined2 <- gather(combined, Name, Fluorescence, starts_with("Mean"))     #change format of the dataframe 
colnames(combined2)[3] <- "Cell"             #change column headers to the correct name
colnames(combined2)[4] <- "Fluorescence"    #change column headers to the correct name
colnames(combined2)[2] <- "Naam"          #change column headers to the correct name

#extra id column, when multiple movies are used
library(dplyr)
detach("package:plyr", unload=TRUE) 
combined3 <- (
  combined2 %>% 
    group_by(X) %>% 
    mutate(id=1:n())
)

#remove cells that have really low fluorescence
combined3 <- (
  combined3 %>%
    group_by(id) %>%
    filter(!any(Fluorescence < 20))
)


#normalize to the first frame of the movie (bleaching curve) (baseline)
combined3normalized <-
  (
    combined3 %>% 
      group_by(Cell, Naam) %>%
      mutate(Fluorescence_norm=Fluorescence/mean(Fluorescence[1])) %>%         
      arrange(Naam, Cell)
  )

# #remove cells that fly away and get really low normalized fluorescence
library(dplyr)
combined3normalized <- (
  combined3normalized %>%
    group_by(Cell, Naam) %>%
    filter(!any(Fluorescence_norm < 0.1))
)


library(plotrix)
#add a variable to each cell in order to seperate cells from 2 different experiments (otherwise 2 cells will have the name mean1 for example)
combined3normalized <-
  (
    combined3normalized %>%
      group_by(Cell, Naam) %>%
      mutate(cellexp=paste(Naam, Cell)) %>%
      arrange(Naam, Cell, X)
  )

combined3normalized <- na.omit(combined3normalized)    #remove cells which do not have fluorescence value
combined3normalized <- as.data.frame(combined3normalized)

# add information about bleaching type/setting
library(mosaic)
combined3normalized <- mutate(combined3normalized, Naam = derivedFactor(
  "CFP + YFP" = str_detect(Naam, "CFPYFPbleach"),
  "RFP + YFP" = str_detect(Naam, "RFPYFP"),
  "CFP + GFP" = str_detect(Naam, "CFPGFPbleach"),
    "RFP + GFP" = str_detect(Naam, "RFPGFPbleach"),
  "YFP + RFP" = str_detect(Naam, "YFPRFPbleach"),
  "GFP + RFP" = str_detect(Naam, "GFPRFPbleach"),
  "CFP + RFP" = str_detect(Naam, "CFPRFPbleach"),
  "GFP + CFP" = str_detect(Naam, "GFPCFPbleach"),
  "RFP + CFP" = str_detect(Naam, "RFPCFPbleach"),
  "YFP + CFP" = str_detect(Naam, "YFPCFPbleach"),
    "RFP" = str_detect(Naam, "RFPbleach"),
  "YFP" = str_detect(Naam, "YFPbleach"),
  "GFP" = str_detect(Naam, "GFPbleach"),
  "CFP" = str_detect(Naam, "CFPbleach"),
      .method = "first",
  .default = 5555
))

#get mean values, SD and SE
errordata <- combined3normalized %>% 
  group_by(X, Naam) %>% 
  summarise_all(funs(mean,sd,std.error))

# add sample size
samplecounts <- length(unique(combined3normalized$cellexp))   #hoeveelheid n in je experiment 
ondertitel2 <- paste(ondertitel1) #ondertitel 1    #zet deze hoeveelheid n in je titel
ondertitel2 <- gsub("\\s(?=\\S\\s\\S{2,}|\\S$)", "", ondertitel2, perl=TRUE)

combined3normalized <-
  combined3normalized %>% 
  group_by(X, Naam) %>% 
  mutate(Naam2=paste(Naam,", n=",length(Naam))) %>% 
  ungroup()

combined3normalized$Naam2 <- gsub("n= ", "n=", combined3normalized$Naam2)

#remove old conditie column and replace with the conditie column that also has the sample size
combined3normalized$Naam <- NULL
combined3normalized$Naam  <- combined3normalized$Naam2
combined3normalized$Naam2 <- NULL

# make data for Daan, separate column for each bleaching type with mean and SD (instead of row)
Data_daan <- errordata[,c(1,2,6,11)]
Data_daan1 <- spread(Data_daan, key=Naam, value = Fluorescence_norm_mean)
colnames(Data_daan1)[1] <- "Timestamp"
Data_daan1$Timestamp <- Data_daan1$Timestamp*3-3
Data_daan1 <- cbind(msec_exposure_time = ((Data_daan1$Timestamp/3)*200+200), Data_daan1)

Data_daan2 <- na.omit(Data_daan1[,c(1,2,4,3)])
colnames(Data_daan2)[4] <- paste(colnames(Data_daan2)[4], colnames(Data_daan2)[3], sep = "_")
colnames(Data_daan2)[3] <- paste("Fluorescence_norm", colnames(Data_daan2)[3], sep = "_")
Data_daan3 <- na.omit(Data_daan1[,c(3,5)])
colnames(Data_daan3)[1] <- paste(colnames(Data_daan3)[1], colnames(Data_daan3)[2], sep = "_")
colnames(Data_daan3)[2] <- paste("Fluorescence_norm", colnames(Data_daan3)[2], sep = "_")
Data_daan4 <- na.omit(Data_daan1[,c(3,6)])
colnames(Data_daan4)[1] <- paste(colnames(Data_daan4)[1], colnames(Data_daan4)[2], sep = "_")
colnames(Data_daan4)[2] <- paste("Fluorescence_norm", colnames(Data_daan4)[2], sep = "_")
Data_daan5 <- na.omit(Data_daan1[,c(3,7)])
colnames(Data_daan5)[1] <- paste(colnames(Data_daan5)[1], colnames(Data_daan5)[2], sep = "_")
colnames(Data_daan5)[2] <- paste("Fluorescence_norm", colnames(Data_daan5)[2], sep = "_")
Data_daan6 <- na.omit(Data_daan1[,c(3,8)])
colnames(Data_daan6)[1] <- paste(colnames(Data_daan6)[1], colnames(Data_daan6)[2], sep = "_")
colnames(Data_daan6)[2] <- paste("Fluorescence_norm", colnames(Data_daan6)[2], sep = "_")

# combine all data into 1 frame
Data_daan2[5] <- Data_daan3[2]
Data_daan2[6] <- Data_daan3[1]
Data_daan2[7] <- Data_daan4[2]
Data_daan2[8] <- Data_daan4[1]
Data_daan2[9] <- Data_daan5[2]
Data_daan2[10] <- Data_daan5[1]
Data_daan2[11] <- Data_daan6[2]
Data_daan2[12] <- Data_daan6[1]
write.csv(Data_daan2, file = paste(titel,"bleaching_data_Daan.csv"), row.names = FALSE)

Data_daan <- NULL
Data_daan1 <- NULL
Data_daan2 <- NULL
Data_daan3 <- NULL
Data_daan4 <- NULL
Data_daan5 <- NULL
Data_daan6 <- NULL

